# ydl-binaries
[![Build Status](https://travis-ci.org/kepoorhampond/ydl-binaries.svg?branch=master)](https://travis-ci.org/kepoorhampond/ydl-binaries)
> :sparkles: A python module that can download and update binaries for ffmpeg and youtube-dl.

Created out of the frustration that ffmpeg causes and the complete lack of easy cross platform access for `youtube-dl` and `ffmpeg`.

## Install
```
$ pip install ydl-binaries
```
